#!/bin/bash

# GET SUDO privilege (Change sudo to gksu or gksudo if you prefer a graphical prompt)
echo "***********************************************"
echo "*           eDRUMin Control Setup             *"
echo "***********************************************"
echo
echo "This installer requires root privileges..."
[ "$UID" -eq 0 ] || exec sudo bash "$0" "$@"

#install dependencies
sudo apt-get install libxcb-cursor-dev libusb-dev

APP_NAME="eDRUMin"
VST3_NAME="edrumin.vst3"
SHORTCUT_NAME="${APP_NAME}.desktop"
BINARY_NAME="${APP_NAME}"

APP_INSTALL_FOLDER="/opt/${APP_NAME}"
USER_HOME=$(getent passwd $SUDO_USER | cut -d: -f6)
SHORTCUT_PATH="/usr/share/applications/${SHORTCUT_NAME}"
RULES_PATH="/etc/udev/rules.d/${APP_NAME}.rules"
PDF="${APP_NAME}.pdf"
ICON_NAME="icon.png"

AF_SETTINGS_PATH="${USER_HOME}/.AudioFront"

ICON_PATH="${AF_SETTINGS_PATH}/${APP_NAME}/${ICON_NAME}"
SETTINGS_PATH="${AF_SETTINGS_PATH}/${APP_NAME}"


#REMOVE OLD STUFF
if [ -d "${APP_INSTALL_FOLDER}" ]; then 
    echo "Uninstalling previous version..."
    rm -r "${APP_INSTALL_FOLDER}"
fi

#create application folder
mkdir -p "${APP_INSTALL_FOLDER}"

echo "Creating folder structure..."
#make firmware folder
mkdir "${APP_INSTALL_FOLDER}/firmware"
mkdir "${APP_INSTALL_FOLDER}/vst3"

#copy the binary
echo "Copying application binaries..."
cp "./bin/${BINARY_NAME}"  "${APP_INSTALL_FOLDER}"
cp -r "./bin/${VST3_NAME}" "${APP_INSTALL_FOLDER}/vst3/"

#copy the firmware
echo "Copying firmware..."
cp -r "./firmware" "${APP_INSTALL_FOLDER}/"


echo "Creating Desktop shortcut..."
echo "[Desktop Entry]" > "${SHORTCUT_PATH}"
echo "Type=Application" >> "${SHORTCUT_PATH}"
echo "Terminal=false" >> "${SHORTCUT_PATH}"
echo "Name=eDRUMin" >> "${SHORTCUT_PATH}"
echo "Icon=${ICON_PATH}" >> "${SHORTCUT_PATH}"
echo "Exec=${APP_INSTALL_FOLDER}/${BINARY_NAME}" >> "${SHORTCUT_PATH}"
echo "StartupNotify=true" >> "${SHORTCUT_PATH}"
echo "StartupWMClass=eDRUMin" >> "${SHORTCUT_PATH}"

chmod 755 "${SHORTCUT_PATH}"
chmod +x "${SHORTCUT_PATH}"


chmod -R 777 "${APP_INSTALL_FOLDER}/firmware"


echo "Adding udev rules..."

if test -f "$RULES_PATH"; then
    rm "${RULES_PATH}"
fi

touch ${RULES_PATH}

echo "# eDRUMin rules to allow access to rawhid devices"  >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0460\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0461\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0462\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0463\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0464\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0465\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0478\", MODE:=\"0666\"" >> "${RULES_PATH}"

udevadm control --reload

#MAKE AUDIOFRONT FOLDER IF IT DOESN'T ALREADY EXIST
if [ -d "${AF_SETTINGS_PATH}" ]; then 
    echo "AudioFront Folder found..."
else
    echo "Creating AudioFront folder..."
    mkdir "${AF_SETTINGS_PATH}"
    chmod 777 "${AF_SETTINGS_PATH}"
fi

#MAKE THE APPLICATION SETTINGS PATH
if [ -d "${SETTINGS_PATH}" ]; then 
    echo "Application settings folder found..."
else
    echo "Creating application settings folder..."
    mkdir "${SETTINGS_PATH}"
    chmod 777 "${SETTINGS_PATH}"
fi


if test -f "${USER_HOME}/.AudioFront/${PDF}"; then
    echo "Removing previous user manual..."
    rm "${USER_HOME}/.AudioFront/${PDF}"
fi

echo "Copying user manual..."
cp "./${PDF}" "${USER_HOME}/.AudioFront/"
chmod 777 "${USER_HOME}/.AudioFront/${PDF}"

echo "Copying application icon..."
cp "./${ICON_NAME}" "${SETTINGS_PATH}"
chown $SUDO_USER "${ICON_PATH}"
chmod 777 "${ICON_PATH}"

echo "Copying factory presets..."
cp -rf "./presets/factory" "${SETTINGS_PATH}"
chown -R $SUDO_USER "${SETTINGS_PATH}/factory"
chmod -R 777 "${SETTINGS_PATH}/factory"


echo "Installation complete."